.. _Contribute:

Contribute
==========
`Feeds uses GitHub`_ as development platform.

Issues
~~~~~~
* Search the existing issues in the `issue tracker`_.
* File a `new issue`_ in case the issue is undocumented.

Pull requests
~~~~~~~~~~~~~
* Fork the project to your private repository.
* Create a topic branch and make your desired changes.
* Open a pull request. Make sure the travis checks are passing.

.. _Feeds uses GitHub: https://github.com/pyfeeds/pyfeeds
.. _issue tracker: https://github.com/pyfeeds/pyfeeds/issues
.. _new issue: https://github.com/pyfeeds/pyfeeds/issues/new
